@@ -251,7 +251,7 @@ our @EXPORT = qw(
     SANE_NAME_LAMP_OFF_AT_EXIT
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 our $DEBUG = 0;
 our ($STATUS, $_status, $_vc);
 
@@ -270,6 +270,18 @@ sub get_version {
 }
 
 
+sub get_version_scalar {
+ if (not $_vc) {
+  print "Running init\n" if $DEBUG;
+  $_vc = Sane->_init;
+  $STATUS = Sane::Status->new;
+  return undef if ($_status);
+ }
+ my @version = Sane->_get_version($_vc);
+ return $version[0]+$version[1]/1000+$version[2]/1000000;
+}
+
+
 sub get_devices {
  if (not $_vc) {
   print "Running init\n" if $DEBUG;
@@ -338,13 +350,13 @@ sub write_pnm_header {
 # to read the image.
 
 # For some reason, the #defines need parentheses here, but not normally
- if ($format == SANE_FRAME_RED() or $format == SANE_FRAME_GREEN() or
-                  $format == SANE_FRAME_BLUE() or $format == SANE_FRAME_RGB()) {
+ if ($format == Sane::SANE_FRAME_RED() or $format == Sane::SANE_FRAME_GREEN() or
+                  $format == Sane::SANE_FRAME_BLUE() or $format == Sane::SANE_FRAME_RGB()) {
   printf $fh "P6\n# SANE data follows\n%d %d\n%d\n", $width, $height,
 	      ($depth <= 8) ? 255 : 65535;
  }
 # For some reason, the #defines need parentheses here, but not normally
- elsif ($format == SANE_FRAME_GRAY()) {
+ elsif ($format == Sane::SANE_FRAME_GRAY()) {
   if ($depth == 1) {
    printf $fh "P4\n# SANE data follows\n%d %d\n", $width, $height;
   }
@@ -408,10 +420,16 @@ as dictated by the SANE standard, or the the corresponding message, as required.
 
 =head2 Sane->get_version
 
-Returns a array with the SANE_VERSION_(MAJOR|MINOR|BUILD) versions:
+Returns an array with the SANE_VERSION_(MAJOR|MINOR|BUILD) versions:
 
   join('.',Sane->get_version)
 
+=head2 Sane->get_version_scalar
+
+Returns an scalar with the SANE_VERSION_(MAJOR|MINOR|BUILD) versions combined
+as per the Perl version numbering, i.e. sane 1.0.19 gives 1.000019. This allows
+simple version comparisons.
+
 =head2 Sane->get_devices
 
 This function can be used to query the list of devices that are available.
@@ -660,7 +678,7 @@ documentation should be considered the canonical source.
 
 =head1 AUTHOR
 
-Jeffrey Ratcliffe, E<lt>Jeffrey.Ratcliffe@gmail.com<gt>
+Jeffrey Ratcliffe, E<lt>Jeffrey.Ratcliffe@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
